@@ -58,22 +58,25 @@ def _convert_error(func):
     def _wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except OSError:
-            raise EnvironmentError("pkg-config is not installed")
-
+        except OSError as e:
+            raise EnvironmentError("pkg-config is probably not installed. Could not run pkg-config: %r"%e)
     return _wrapper
 
 
 @_convert_error
-def _query(package, option):
+def _query(package, *options):
     pkg_config_exe = os.environ.get('PKG_CONFIG', None) or 'pkg-config'
-    cmd = '{0} {1} {2}'.format(pkg_config_exe, option, package)
+    cmd = '{0} {1} {2}'.format(pkg_config_exe, ' '.join(options), package)
     proc = Popen(shlex.split(cmd), stdout=PIPE, stderr=PIPE)
     out, err = proc.communicate()
 
     return out.rstrip().decode('utf-8')
 
 
+def _build_options(option, static=False):
+    return (option, '--static') if static else (option,)
+
+
 @_convert_error
 def exists(package):
     """
@@ -105,9 +108,15 @@ def cflags(package):
     return _query(package, '--cflags')
 
 
-def libs(package):
-    """Return the LDFLAGS string returned by pkg-config."""
-    return _query(package, '--libs')
+def libs(package, static=False):
+    """
+    Return the LDFLAGS string returned by pkg-config.
+
+    The static specifier will also include libraries for static linking (i.e.,
+    includes any private libraries).
+    """
+
+    return _query(package, *_build_options('--libs', static=static))
 
 
 def variables(package):
@@ -178,47 +187,35 @@ _PARSE_MAP = {
 }
 
 
-def parse(packages):
+def parse(packages, static=False):
     """
     Parse the output from pkg-config about the passed package or packages.
 
-    Builds a dictionary containing the 'libraries', the 'library_dirs',
-    the 'include_dirs', and the 'define_macros' that are presented by
-    pkg-config. *package* is a string with space-delimited package names.
+    Builds a dictionary containing the 'libraries', the 'library_dirs', the
+    'include_dirs', and the 'define_macros' that are presented by pkg-config.
+    *package* is a string with space-delimited package names.
 
-    If ``pkg-config`` not on path, raises ``EnvironmentError``.
+    The static specifier will also include libraries for static linking (i.e.,
+    includes any private libraries).
+
+    If ``pkg-config`` is not on path, raises ``EnvironmentError``.
     """
-    def parse_package(package):
-        result = collections.defaultdict(list)
+    out = _query(packages, *_build_options('--cflags --libs', static=static))
+    out = out.replace('\\"', '')
+    result = collections.defaultdict(list)
 
-        # Execute the query to pkg-config and clean the result.
-        out = _query(package, '--cflags --libs')
-        out = out.replace('\\"', '')
+    for token in re.split(r'(?<!\\) ', out):
+        key = _PARSE_MAP.get(token[:2])
+        if key:
+            result[key].append(token[2:].strip())
 
-        # Iterate through each token in the output.
-        for token in re.split(r'(?<!\\) ', out):
-            key = _PARSE_MAP.get(token[:2])
-            if key:
-                result[key].append(token[2:].strip())
+    def split(m):
+        t = tuple(m.split('='))
+        return t if len(t) > 1 else (t[0], None)
 
-        # Iterate and clean define macros.
-        macros = list()
-        for declaration in result['define_macros']:
-            macro = tuple(declaration.split('='))
-            if len(macro) == 1:
-                macro += None,
+    result['define_macros'] = [split(m) for m in result['define_macros']]
 
-            macros.append(macro)
-
-        result['define_macros'] = macros
-
-        # Return parsed configuration.
-        return result
-
-    # Return the result of parse_package directly.
-    # We don't need to loop over the packages
-
-    return parse_package(packages)
+    return result
 
 
 def list_all():
